@@ -7,7 +7,7 @@ package Dist::Zilla::PluginBundle::Author::KENTNL;
 
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
 
-our $VERSION = '2.014001';
+our $VERSION = '2.015000';
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
@@ -15,6 +15,7 @@ use Moose qw( with has );
 use Moose::Util::TypeConstraints qw(enum);
 use MooseX::StrictConstructor;
 use MooseX::AttributeShortcuts;
+use Dist::Zilla::Util::CurrentCmd qw( current_cmd );
 
 with 'Dist::Zilla::Role::PluginBundle';
 with 'Dist::Zilla::Role::BundleDeps';
@@ -400,43 +401,54 @@ sub add_named_plugin {
 
 
 
-sub configure {
-  my ($self) = @_;
+sub _is_bake { return ( current_cmd() and 'bakeini' eq current_cmd() ) }
 
-  # Version
-  if ( not $self->bumpversions ) {
-    $self->add_plugin(
-      'Git::NextVersion::Sanitized' => {
-        version_regexp => '^(.*)-source$',
-        first_version  => '0.001000',
-        normal_form    => $self->normal_form,
-        mantissa       => $self->mantissa,
-      },
-    );
-  }
+sub _configure_bumpversions_version {
+  my ( $self, ) = @_;
+  return if $self->bumpversions;
+  $self->add_plugin(
+    'Git::NextVersion::Sanitized' => {
+      version_regexp => '^(.*)-source$',
+      first_version  => '0.001000',
+      normal_form    => $self->normal_form,
+      mantissa       => $self->mantissa,
+    },
+  );
+  return;
+}
 
-  # Metadata
-  $self->add_plugin( 'MetaConfig' => {}, );
-
-  $self->add_plugin( 'GithubMeta' => { issues => 1 }, );
+sub _configure_basic_metadata {
+  my ( $self, ) = @_;
 
+  $self->add_plugin( 'MetaConfig'            => {}, );
+  $self->add_plugin( 'GithubMeta'            => { issues => 1 }, );
   $self->add_plugin( 'MetaProvides::Package' => { ':version' => '1.14000001' }, );
 
+  my $builtwith_options = { show_config => 1 };
+
   if ( 'linux' eq $^O ) {
-    $self->add_plugin( 'MetaData::BuiltWith' => { show_uname => 1, uname_args => q{-s -o -r -m -i}, show_config => 1 }, );
-  }
-  else {
-    $self->add_plugin( 'MetaData::BuiltWith' => { show_config => 1 } );
+    $builtwith_options->{show_uname} = 1;
+    $builtwith_options->{uname_args} = q{-s -o -r -m -i};
   }
 
-  # Gather Files
+  $self->add_plugin( 'MetaData::BuiltWith' => $builtwith_options );
 
+  return;
+}
+
+sub _configure_basic_files {
+  my ($self) = @_;
   $self->add_plugin( 'Git::GatherDir' => { include_dotfiles => 1 } );
   $self->add_plugin( 'License'        => {} );
   $self->add_plugin( 'MetaJSON'       => {} );
   $self->add_plugin( 'MetaYAML'       => {} );
   $self->add_plugin( 'Manifest'       => {} );
-  $self->add_plugin( 'MetaTests'      => {} );
+  return;
+}
+
+sub _configure_basic_tests {
+  my ($self) = @_;
+  $self->add_plugin( 'MetaTests'              => {} );
   $self->add_plugin( 'PodCoverageTests'       => {} );
   $self->add_plugin( 'PodSyntaxTests'         => {} );
   $self->add_plugin( 'Test::ReportPrereqs'    => {} );
@@ -445,23 +457,132 @@ sub configure {
   $self->add_plugin( 'Test::MinimumVersion'   => {} );
   $self->add_plugin( 'Test::Compile::PerFile' => {} );
   $self->add_plugin( 'Test::Perl::Critic'     => {} );
+  return;
+}
+
+sub _configure_pkgversion_munger {
+  my ($self) = @_;
+  if ( not $self->bumpversions ) {
+    $self->add_plugin( 'PkgVersion' => {} );
+    return;
+  }
+  $self->add_plugin(
+    'RewriteVersion::Sanitized' => {
+      normal_form => $self->normal_form,
+      mantissa    => $self->mantissa,
+    },
+  );
+  return;
+}
+
+sub _configure_bundle_develop_suggests {
+  my ($self) = @_;
+  my $deps = {
+    -phase => 'develop',
+    -type  => 'suggests',
+  };
+  if ( _is_bake() ) {
+    $deps->{'Dist::Zilla::PluginBundle::Author::KENTNL'} = $VERSION;
+    $deps->{'Dist::Zilla::App::Command::bakeini'}        = '0.001000';
+  }
+  else {
+    $deps->{'Dist::Zilla::PluginBundle::Author::KENTNL::Lite'} = '1.3.0';
+  }
+  $self->add_named_plugin( 'BundleDevelSuggests' => 'Prereqs' => $deps );
+  return;
+}
+
+sub _configure_bundle_develop_requires {
+  my ($self) = @_;
+  return if _is_bake();
+  $self->add_named_plugin(
+    'BundleDevelRequires' => 'Prereqs' => {
+      -phase                                      => 'develop',
+      -type                                       => 'requires',
+      'Dist::Zilla::PluginBundle::Author::KENTNL' => $VERSION,
+    },
+  );
+  return;
+}
+
+sub _configure_toolkit {
+  my ($self) = @_;
+  my $tk = $self->toolkit;
+  if ( 'mb' eq $tk ) {
+    $self->add_plugin( 'ModuleBuild' => { default_jobs => 10 } );
+    return;
+  }
+  if ( 'eumm' eq $tk ) {
+    $self->add_plugin( 'MakeMaker' => { default_jobs => 10 } );
+    return;
+  }
+  if ( 'mbtiny' eq $tk ) {
+    $self->add_plugin( 'ModuleBuildTiny' => { default_jobs => 10 } );
+    return;
+  }
+  return;
+}
+
+sub _configure_toolkit_prereqs {
+  my ($self) = @_;
+
+  my @extra_match_installed = qw( Test::More );
+  unshift @extra_match_installed, 'Module::Build'       if 'mb' eq $self->toolkit;
+  unshift @extra_match_installed, 'Module::Build::Tiny' if 'mbtiny' eq $self->toolkit;
+  unshift @extra_match_installed, 'ExtUtils::MakeMaker' if 'eumm' eq $self->toolkit;
+
+  if ( 'hard' eq $self->toolkit_hardness ) {
+    $self->add_plugin(
+      'Prereqs::MatchInstalled' => {
+        modules => \@extra_match_installed,
+      },
+    );
+  }
+  if ( 'soft' eq $self->toolkit_hardness ) {
+    $self->add_plugin(
+      'Prereqs::Recommend::MatchInstalled' => {
+        modules => \@extra_match_installed,
+      },
+    );
+  }
+
+  my $applymap = [ 'develop.requires = develop.requires', ];
+
+  $applymap = [ 'develop.suggests = develop.suggests', ] if _is_bake();
+
+  my @bundles = ('Dist::Zilla::PluginBundle::Author::KENTNL');
+
+  push @bundles, 'Dist::Zilla::App::Command::bakeini' if _is_bake();
+
+  $self->add_named_plugin(
+    'always_latest_develop_bundle' => 'Prereqs::Recommend::MatchInstalled' => {
+      applyto_map   => $applymap,
+      applyto_phase => [ 'develop', ],
+      modules       => [@bundles],
+    },
+  );
+  return;
+}
+
+sub configure {
+  my ($self) = @_;
+
+  # Version
+  $self->_configure_bumpversions_version;
+
+  # MetaData
+  $self->_configure_basic_metadata;
+
+  # Gather Files
+  $self->_configure_basic_files;
+  $self->_configure_basic_tests;
 
   # Prune files
 
   $self->add_plugin( 'ManifestSkip' => {} );
 
   # Mungers
-  if ( $self->bumpversions ) {
-    $self->add_plugin(
-      'RewriteVersion::Sanitized' => {
-        normal_form => $self->normal_form,
-        mantissa    => $self->mantissa,
-      },
-    );
-  }
-  else {
-    $self->add_plugin( 'PkgVersion' => {} );
-  }
+  $self->_configure_pkgversion_munger;
   $self->add_plugin(
     'PodWeaver' => {
       replacer => 'replace_with_blank',
@@ -475,20 +596,9 @@ sub configure {
     $autoprereqs_hash->{skips} = $self->auto_prereqs_skip if $self->has_auto_prereqs_skip;
     $self->add_plugin( 'AutoPrereqs' => $autoprereqs_hash );
   }
-  $self->add_named_plugin(
-    'BundleDevelSuggests' => 'Prereqs' => {
-      -phase                                            => 'develop',
-      -type                                             => 'suggests',
-      'Dist::Zilla::PluginBundle::Author::KENTNL::Lite' => '1.3.0',
-    },
-  );
-  $self->add_named_plugin(
-    'BundleDevelRequires' => 'Prereqs' => {
-      -phase                                      => 'develop',
-      -type                                       => 'requires',
-      'Dist::Zilla::PluginBundle::Author::KENTNL' => '1.3.0',
-    },
-  );
+
+  $self->_configure_bundle_develop_suggests();
+  $self->_configure_bundle_develop_requires();
 
   $self->add_plugin( 'MinimumPerl' => {} );
   $self->add_plugin(
@@ -500,9 +610,7 @@ sub configure {
     },
   );
 
-  $self->add_plugin( 'ModuleBuild'     => { default_jobs => 10 } ) if 'mb' eq $self->toolkit;
-  $self->add_plugin( 'MakeMaker'       => { default_jobs => 10 } ) if 'eumm' eq $self->toolkit;
-  $self->add_plugin( 'ModuleBuildTiny' => { default_jobs => 10 } ) if 'mbtiny' eq $self->toolkit;
+  $self->_configure_toolkit;
 
   $self->add_plugin( 'ReadmeFromPod' => {} );
   $self->add_plugin(
@@ -541,33 +649,8 @@ sub configure {
     },
   );
 
-  my @extra_match_installed = qw( Test::More );
-  unshift @extra_match_installed, 'Module::Build'       if 'mb' eq $self->toolkit;
-  unshift @extra_match_installed, 'Module::Build::Tiny' if 'mbtiny' eq $self->toolkit;
-  unshift @extra_match_installed, 'ExtUtils::MakeMaker' if 'eumm' eq $self->toolkit;
+  $self->_configure_toolkit_prereqs;
 
-  if ( 'hard' eq $self->toolkit_hardness ) {
-    $self->add_plugin(
-      'Prereqs::MatchInstalled' => {
-        modules => \@extra_match_installed,
-      },
-    );
-  }
-  if ( 'soft' eq $self->toolkit_hardness ) {
-    $self->add_plugin(
-      'Prereqs::Recommend::MatchInstalled' => {
-        modules => \@extra_match_installed,
-      },
-    );
-  }
-
-  $self->add_named_plugin(
-    'always_latest_develop_bundle' => 'Prereqs::Recommend::MatchInstalled' => {
-      applyto_map   => [ 'develop.requires = develop.requires', ],
-      applyto_phase => [ 'develop', ],
-      modules       => [ qw( Dist::Zilla::PluginBundle::Author::KENTNL ), ],
-    },
-  );
   return;
 }
 
@@ -604,7 +687,7 @@ Dist::Zilla::PluginBundle::Author::KENTNL - BeLike::KENTNL when you build your d
 
 =head1 VERSION
 
-version 2.014001
+version 2.015000
 
 =head1 SYNOPSIS
 
